@@ -15,7 +15,7 @@
               "Describe variable: "
               (emacsy-collect-kind (current-module) 'variable 1)
               #:to-string symbol->string)))
-  #;(message "Describing variable ~a: ~a" symbol (variable-documentation symbol))
+  ;;(message "Describing variable ~a: ~a" symbol (variable-documentation symbol))
   (message "~a" (variable-documentation symbol)))
 
 (define-interactive 
@@ -25,7 +25,7 @@
               "Describe command: "
               (emacsy-collect-kind (current-module) 'command 1)
               #:to-string symbol->string)))
-  #;(message "Describing variable ~a: ~a" symbol (variable-documentation symbol))
+  ;;(message "Describing variable ~a: ~a" symbol (variable-documentation symbol))
   (message "~a" (procedure-documentation (module-ref (current-module) symbol))))
 
 (define-key global-map "C-h v" 'describe-variable)
