@@ -176,8 +176,10 @@ available. Otherwise returns default-ticks."
                   result
                   stream-null)))))
         stream-null)))
+(define (required-arguments proc)
+  (assoc-ref (program-arguments-alist proc) 'required))
 (define (readline-completer? proc)
-  (let ((req (arity:nreq (car (program-arities proc)))))
+  (let ((req (length (required-arguments proc))))
     (= req 2)))
 
 (define*-public 
@@ -345,25 +347,27 @@ available. Otherwise returns default-ticks."
 
 (define-public (history-insert! history value)
   (cursor-right-insert! history value)
-  #;(fluid-set! minibuffer-history
-              (list-insert! (fluid-ref minibuffer-history)
-                         index
-                         value)))
+  ;;(fluid-set! minibuffer-history
+  ;;            (list-insert! (fluid-ref minibuffer-history)
+  ;;                       index
+  ;;                       value))
+  )
 
 (define-public (history-ref history)
   (if (cursor-right? history)
    (cursor-right-ref history)
    #f)
-  #;(list-ref (fluid-ref minibuffer-history) index))
+  ;;(list-ref (fluid-ref minibuffer-history) index)
+  )
 
 (define-public (history-set! history value)
       (cursor-right-set! history value)
-      #;(if (cursor-right? history)
-      (cursor-right-set! history value)
-      (cursor-right-insert! history value))
-  #;(let ((lst (fluid-ref minibuffer-history)))
-    (list-set! lst index value)
-    (fluid-set! minibuffer-history lst))
+      ;;(if (cursor-right? history)
+      ;;(cursor-right-set! history value)
+      ;;(cursor-right-insert! history value))
+  ;;(let ((lst (fluid-ref minibuffer-history)))
+  ;;  (list-set! lst index value)
+  ;;  (fluid-set! minibuffer-history lst))
   value)
 (define-interactive (exit-minibuffer)
   (set! minibuffer-reading? #f)
@@ -422,14 +426,16 @@ available. Otherwise returns default-ticks."
            (cursor-left! minibuffer-history)
            (previous-history-element* (1- n)))
          (begin (minibuffer-message " [Beginning of history; no preceding item]")
-                #;(previous-history-element 0))))
+                ;;(previous-history-element 0)
+                )))
     ((< n 0)
      (if (cursor-right? minibuffer-history 2)
          (begin 
            (cursor-right! minibuffer-history)
            (previous-history-element* (1+ n)))
          (begin (minibuffer-message " [End of history; no default available]")
-                #;(previous-history-element 0))))
+                ;;(previous-history-element 0)
+                )))
     ((= n 0)
      #f)))
   ;;
@@ -441,23 +447,24 @@ available. Otherwise returns default-ticks."
 (format #t "minibuffer-history ~a~%" minibuffer-history)
 (history-ref minibuffer-history)
 
-  #;(let* ((i (fluid-ref minibuffer-history-index))
-         (j (+ i n))
-         (history (fluid-ref minibuffer-history)))
-    (pretty-print history)
-    (pretty-print i)
-    (pretty-print j)
-    (cond ((< j 0)
-           )
-          ((>= j (length history))
-           (minibuffer-message " [Beginning of history; no preceding item]"))
-          (else
-           (history-set! i (minibuffer-contents))
-           (with-buffer minibuffer
-            (goto-char (point-min)))
-           (delete-minibuffer-contents minibuffer)
-           (insert (list-ref history j))
-           (fluid-set! minibuffer-history-index j)))))
+  ;;(let* ((i (fluid-ref minibuffer-history-index))
+  ;;       (j (+ i n))
+  ;;       (history (fluid-ref minibuffer-history)))
+  ;;  (pretty-print history)
+  ;;  (pretty-print i)
+  ;;  (pretty-print j)
+  ;;  (cond ((< j 0)
+  ;;         )
+  ;;        ((>= j (length history))
+  ;;         (minibuffer-message " [Beginning of history; no preceding item]"))
+  ;;        (else
+  ;;         (history-set! i (minibuffer-contents))
+  ;;         (with-buffer minibuffer
+  ;;         (goto-char (point-min)))
+  ;;         (delete-minibuffer-contents minibuffer)
+  ;;         (insert (list-ref history j))
+  ;;         (fluid-set! minibuffer-history-index j))))
+     )
 
 (define-interactive (next-history-element #:optional (n 1))
   (previous-history-element (- n)))
